"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDebounce = void 0;
const react_1 = require("react");
/**
 * Custom hook to debounce a function.
 * @param callback The function to debounce.
 * @param delay The delay time in milliseconds.
 * @returns A debounced version of the provided function.
 */
function useDebounce(callback, delay) {
    const timeoutRef = (0, react_1.useRef)(null);
    const callbackRef = (0, react_1.useRef)(callback);
    const isMountedRef = (0, react_1.useRef)(true);
    (0, react_1.useEffect)(() => {
        callbackRef.current = callback;
    }, [callback]);
    (0, react_1.useEffect)(() => {
        isMountedRef.current = true;
        return () => {
            isMountedRef.current = false;
            timeoutRef.current && clearTimeout(timeoutRef.current);
        };
    }, []);
    const debounced = (...args) => {
        if (timeoutRef.current) {
            clearTimeout(timeoutRef.current);
        }
        timeoutRef.current = setTimeout(() => {
            if (isMountedRef.current) {
                callbackRef.current(...args);
            }
        }, delay);
    };
    return debounced;
}
exports.useDebounce = useDebounce;
